@@ -1,7 +1,7 @@
-from .scala import *
 from .file import *
 from .html import *
 from .nu_nl import *
 from .rss import *
 from .text import *
 from .bcc import *
+from .scalascript import *
