@@ -5,6 +5,10 @@ import shutil
 import requests
 from .scalascript import *
 import xml.etree.ElementTree as ET
+from tempfile import gettempdir
+
+tempfolder = gettempdir()
+localintegratedfolder = "C:/Users/Public/Documents/Scala/LocalIntegratedContent"
 
 
 def create_directories(directories):
